@@ -128,7 +128,7 @@ sub handle_feed {
         $entry->link($e->link);
         $entry->feed_link($feed->link);
         $entry->id($e->id);
-        $entry->body($e->content->body);
+        $entry->body($e->content->body || $e->summary->body);
 
         my $args = {
             entry      => $entry,
