@@ -2,7 +2,7 @@ package Plagger::UserAgent;
 use strict;
 use base qw( LWP::UserAgent );
 
-use URI::Fetch;
+use URI::Fetch 0.05;
 
 sub new {
     my $class = shift;
@@ -18,8 +18,13 @@ sub fetch {
     URI::Fetch->fetch($url,
         UserAgent => $self,
         $plugin ? (Cache => $plugin->cache) : (),
+        ForceResponse => 1,
     );
 }
 
+# xxx
+*URI::Fetch::Response::is_success = sub { $_[0]->http_response->is_success };
+*URI::Fetch::Response::is_error   = sub { $_[0]->http_response->is_error };
+
 1;
 
